==> libvirt_2.5.0.orig.tar.xz: libvirt-2.5.0/src/conf/node_device_event.h <==
/*
 * node_device_event.h: node device event queue processing helpers
 *
 * Copyright (C) 2010-2014 Red Hat, Inc.
 * Copyright (C) 2008 VirtualIron
 * Copyright (C) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

#include "internal.h"
#include "object_event.h"
#include "object_event_private.h"

#ifndef __NODE_DEVICE_EVENT_H__
# define __NODE_DEVICE_EVENT_H__

int
virNodeDeviceEventStateRegisterID(virConnectPtr conn,
                                  virObjectEventStatePtr state,
                                  virNodeDevicePtr dev,
                                  int eventID,
                                  virConnectNodeDeviceEventGenericCallback cb,
                                  void *opaque,
                                  virFreeCallback freecb,
                                  int *callbackID)
    ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(5)
    ATTRIBUTE_NONNULL(8);

int
virNodeDeviceEventStateRegisterClient(virConnectPtr conn,
                                      virObjectEventStatePtr state,
                                      virNodeDevicePtr dev,
                                      int eventID,
                                      virConnectNodeDeviceEventGenericCallback cb,
                                      void *opaque,
                                      virFreeCallback freecb,
                                      int *callbackID)
    ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(5)
    ATTRIBUTE_NONNULL(8);

virObjectEventPtr
virNodeDeviceEventLifecycleNew(const char *name,
                               int type,
                               int detail);

virObjectEventPtr
virNodeDeviceEventUpdateNew(const char *name);

#endif

==> libvirt_5.0.0.orig.tar.xz: libvirt-5.0.0/src/conf/node_device_event.h <==
/*
 * node_device_event.h: node device event queue processing helpers
 *
 * Copyright (C) 2010-2014 Red Hat, Inc.
 * Copyright (C) 2008 VirtualIron
 * Copyright (C) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

#ifndef LIBVIRT_NODE_DEVICE_EVENT_H
# define LIBVIRT_NODE_DEVICE_EVENT_H

# include "internal.h"
# include "object_event.h"
# include "object_event_private.h"

int
virNodeDeviceEventStateRegisterID(virConnectPtr conn,
                                  virObjectEventStatePtr state,
                                  virNodeDevicePtr dev,
                                  int eventID,
                                  virConnectNodeDeviceEventGenericCallback cb,
                                  void *opaque,
                                  virFreeCallback freecb,
                                  int *callbackID)
    ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(5)
    ATTRIBUTE_NONNULL(8);

int
virNodeDeviceEventStateRegisterClient(virConnectPtr conn,
                                      virObjectEventStatePtr state,
                                      virNodeDevicePtr dev,
                                      int eventID,
                                      virConnectNodeDeviceEventGenericCallback cb,
                                      void *opaque,
                                      virFreeCallback freecb,
                                      int *callbackID)
    ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(5)
    ATTRIBUTE_NONNULL(8);

virObjectEventPtr
virNodeDeviceEventLifecycleNew(const char *name,
                               int type,
                               int detail);

virObjectEventPtr
virNodeDeviceEventUpdateNew(const char *name);

#endif /* LIBVIRT_NODE_DEVICE_EVENT_H */
